/**
 * Checks if there is a new version of the CLI available on npm.
 *
 * @returns `undefined` if there is no upgrade available. If there is a new
 * version, returns an object with `latest` (the latest version) and `current`
 * (the current version).
 */
export declare function upgradeAvailable(): {
    latest: string | undefined;
    current: any;
} | undefined;
/**
 * Returns the latest version of an npm module. The version is cached for 30min
 * to ~/.cdk8s-cli.version.
 *
 * Never throws.
 *
 * @param module The module name
 * @param options cache options
 */
export declare function getLatestVersion(module: string, options: {
    cacheFile: string;
    cacheTtlSec: number;
}): string | undefined;
